@@ -1,6 +1,6 @@
 // Filename: load_store_unit.rs
-// Version:	 0.1
-// Date:	 24-09-2021 (DD-MM-YYYY)
+// Version:	 0.2
+// Date:	 11-10-2021 (DD-MM-YYYY)
 // Library:  gpcas_cpu_model
 //
 // Copyright (c) 2021 Kai Rese
@@ -26,7 +26,7 @@ use serde::{Deserialize, Serialize};
 ///
 /// It is responsible for connecting the core to the memory hierarchy.
 /// It manages in-flight requests.
-#[derive(Default, Deserialize, Serialize)]
+#[derive(Clone, Default, Deserialize, Serialize)]
 pub struct LoadStoreUnitConfig {
     /// The amount of load requests that can be in-flight.
     pub load_count: usize,
