@@ -1,6 +1,6 @@
 // Filename: pipeline.rs
-// Version:	 0.6
-// Date:	 01-10-2021 (DD-MM-YYYY)
+// Version:	 0.9
+// Date:	 19-11-2021 (DD-MM-YYYY)
 // Library:  gpcas_cpu_model
 //
 // Copyright (c) 2021 Kai Rese
@@ -29,7 +29,7 @@ use serde::{Deserialize, Serialize};
 /// and/or AGU and access to the Load-Store-Unit.
 /// As there can be many different things happening in the back-end, a pipeline is highly
 /// configurable.
-#[derive(Deserialize, Serialize)]
+#[derive(Clone, Deserialize, Serialize)]
 pub struct PipelineConfig {
     /// The ID of the scheduler the pipeline uses, if any. Multiple pipelines with the same
     /// scheduler ID share a scheduler among them.
@@ -47,9 +47,6 @@ pub struct PipelineConfig {
     pub memory_load: bool,
     /// If the pipeline can serve memory write operands.
     pub memory_store: bool,
-    /// If the pipeline can serve ALU instructions that also have a memory operand. If this is the
-    /// case, there needs to be an AGU and the memory stage is set before the ALU stage.
-    pub fused_memory_alu: bool,
     /// If the pipeline makes use of register renaming. If it doesn't, an instruction can only be
     /// issued to this pipeline if every register operand is ready and the output register doesn't
     /// have an instruction already wanting to write to it.
@@ -57,7 +54,7 @@ pub struct PipelineConfig {
 }
 
 /// A flag for each instruction class, defining if an ALU supports it.
-#[derive(Deserialize, Serialize)]
+#[derive(Clone, Deserialize, Serialize)]
 pub struct AluCapabilities {
     /// Simple integer addition.
     pub integer_add: bool,
@@ -99,8 +96,6 @@ impl AluCapabilities {
             // float-mul-add
             self.float_mul,
             self.branch,
-            // jumps
-            self.branch,
         ]
     }
 }
