@@ -1,6 +1,6 @@
 // Filename: scheduler.rs
-// Version:	 0.1
-// Date:	 15-09-2021 (DD-MM-YYYY)
+// Version:	 0.3
+// Date:	 27-10-2021 (DD-MM-YYYY)
 //
 // Copyright (c) 2021 Kai Rese
 // This program is free software: you can redistribute it and/or modify
@@ -20,16 +20,16 @@
 use serde::{Deserialize, Serialize};
 
 /// The properties of the register file.
-#[derive(Default, Deserialize, Serialize)]
+#[derive(Clone, Default, Deserialize, Serialize)]
 pub struct RegisterFileConfig {
     /// If the register file supports renaming.
-    renaming: bool,
+    pub renaming: bool,
     /// The number of physical general purpose registers.
     ///
     /// If not set, defaults to the number of architectural general purpose registers.
-    general_purpose_register_count: Option<usize>,
+    pub general_purpose_register_count: Option<usize>,
     /// The number of physical vector registers.
     ///
     /// If not set, defaults to the number of architectural vector registers.
-    vector_register_count: Option<usize>,
+    pub vector_register_count: Option<usize>,
 }
