@@ -1,6 +1,6 @@
 // Filename: v1.rs
-// Version:	 0.1
-// Date:	 24-09-2021 (DD-MM-YYYY)
+// Version:	 0.3
+// Date:	 04-11-2021 (DD-MM-YYYY)
 // Library:  gpcas_cpu_model
 //
 // Copyright (c) 2021 Kai Rese
@@ -20,6 +20,8 @@
 
 //! Data structures for file version 1.
 
+use super::v0::FetchConfig as V0FetchConfig;
+use super::v2::{CPUModel as V2Model, PipelineConfig as V2PipelineConfig};
 use crate::{component_config, CPUModel as NewModel};
 
 use serde::{Deserialize, Serialize};
@@ -32,7 +34,7 @@ pub struct CPUModel {
     /// The ALU latency of each instruction class.
     pub execution_latencies: crate::InstructionLatencies,
     /// Configuration for the fetch stage of the front end.
-    pub fetch_config: component_config::FetchConfig,
+    pub fetch_config: V0FetchConfig,
     /// Configuration for the memory controller.
     pub memory_controller_config: component_config::MemoryControllerConfig,
     /// Caches of the memory hierarchy.
@@ -44,7 +46,7 @@ pub struct CPUModel {
     /// Configuration of schedulers.
     pub schedulers: Vec<component_config::SchedulerConfig>,
     /// Configuration for each pipeline from front end to the last stage.
-    pub pipelines: Vec<super::v1::PipelineConfig>,
+    pub pipelines: Vec<PipelineConfig>,
 }
 
 /// The properties of a CPU pipeline.
@@ -89,12 +91,9 @@ impl From<CPUModel> for NewModel {
             pipelines,
         } = old;
 
-        let pipelines = pipelines
-            .into_iter()
-            .map(component_config::PipelineConfig::from)
-            .collect();
+        let pipelines = pipelines.into_iter().map(V2PipelineConfig::from).collect();
 
-        Self {
+        V2Model {
             max_vector_size,
             execution_latencies,
             fetch_config,
@@ -114,10 +113,11 @@ impl From<CPUModel> for NewModel {
                 cache_connection: None,
             },
         }
+        .into()
     }
 }
 
-impl From<PipelineConfig> for component_config::PipelineConfig {
+impl From<PipelineConfig> for V2PipelineConfig {
     fn from(old: PipelineConfig) -> Self {
         let PipelineConfig {
             scheduler_id,
@@ -130,7 +130,7 @@ impl From<PipelineConfig> for component_config::PipelineConfig {
             renaming,
         } = old;
 
-        component_config::PipelineConfig {
+        V2PipelineConfig {
             scheduler_id,
             register_read_cycles: 0,
             general_purpose,
